Trait Fill

trait Fill

Types which may be filled with random data

This trait allows arrays to be efficiently filled with random data.

Implementations are expected to be portable across machines unless clearly documented otherwise (see the Chapter on Portability).

Required Methods

fn fill<R: Rng + ?Sized>(self: &mut Self, rng: &mut R)

Fill self with random data

Implementors