Struct Iter
struct Iter<D, R, T> { ... }
An iterator over a Distribution
This iterator yields random values of type T with distribution D
from a random generator of type R.
Construct this struct using Distribution::sample_iter or
Rng::sample_iter. It is also used by Rng::random_iter and
crate::random_iter.
Implementations
impl<D, R, T> Freeze for Iter<D, R, T>
impl<D, R, T> FusedIterator for Iter<D, R, T>
impl<D, R, T> Iterator for Iter<D, R, T>
fn next(self: &mut Self) -> Option<T>fn size_hint(self: &Self) -> (usize, Option<usize>)
impl<D, R, T> RefUnwindSafe for Iter<D, R, T>
impl<D, R, T> Send for Iter<D, R, T>
impl<D, R, T> Sync for Iter<D, R, T>
impl<D, R, T> Unpin for Iter<D, R, T>
impl<D, R, T> UnsafeUnpin for Iter<D, R, T>
impl<D, R, T> UnwindSafe for Iter<D, R, T>
impl<D: $crate::fmt::Debug, R: $crate::fmt::Debug, T: $crate::fmt::Debug> Debug for Iter<D, R, T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<I> IntoIterator for Iter<D, R, T>
fn into_iter(self: Self) -> I
impl<I> IteratorRandom for Iter<D, R, T>
impl<T> Any for Iter<D, R, T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Iter<D, R, T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Iter<D, R, T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for Iter<D, R, T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Iter<D, R, T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Iter<D, R, T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Iter<D, R, T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<V, T> VZip for Iter<D, R, T>
fn vzip(self: Self) -> V